@@ -1,5 +1,5 @@
 package experimental;
-$experimental::VERSION = '0.023';
+$experimental::VERSION = '0.026';
 use strict;
 use warnings;
 use version ();
@@ -18,14 +18,18 @@ my %features = map { $_ => 1 } $] > 5.015006 ? keys %feature::feature : do {
 };
 
 my %min_version = (
+	args_array_with_signatures => '5.20.0',
 	array_base      => '5',
 	autoderef       => '5.14.0',
 	bitwise         => '5.22.0',
+	builtin         => '5.35.9',
 	const_attr      => '5.22.0',
 	current_sub     => '5.16.0',
 	declared_refs   => '5.26.0',
+	defer           => '5.35.4',
 	evalbytes       => '5.16.0',
 	fc              => '5.16.0',
+	for_list        => '5.35.5',
 	isa             => '5.31.7',
 	lexical_topic   => '5.10.0',
 	lexical_subs    => '5.18.0',
@@ -38,7 +42,7 @@ my %min_version = (
 	signatures      => '5.20.0',
 	state           => '5.10.0',
 	switch          => '5.10.0',
-	try             => '5.33.6',
+	try             => '5.34.0',
 	unicode_eval    => '5.16.0',
 	unicode_strings => '5.12.0',
 );
@@ -72,12 +76,8 @@ sub _enable {
 		croak "Can't enable unknown feature $pragma";
 	}
 	elsif ($] < $min_version{$pragma}) {
-		my $stable = $min_version{$pragma};
-		if ($stable->{version}[1] % 2) {
-			$stable = version->new(
-				"5.".($stable->{version}[1]+1).'.0'
-			);
-		}
+		my $stable = $min_version{$pragma}->stringify;
+		$stable =~ s/^ 5\. ([0-9]?[13579]) \. \d+ $/"5." . ($1 + 1) . ".0"/xe;
 		croak "Need perl $stable or later for feature $pragma";
 	}
 	elsif ($] >= ($removed_in_version{$pragma} || 7)) {
@@ -135,7 +135,7 @@ experimental - Experimental features made easy
 
 =head1 VERSION
 
-version 0.023
+version 0.026
 
 =head1 SYNOPSIS
 
@@ -233,6 +233,10 @@ incompatibilities between 5.10.0 and 5.10.1.
 
 This was added in perl 5.10.0.
 
+=item * C<try> - allow the use of C<try> and C<catch>
+
+This was added in perl 5.34.0
+
 =item * C<win32_perlio> - allows the use of the :win32 IO layer.
 
 This was added on perl 5.22.0.
